pub struct IrSourced;Expand description
Proposition: The VerifiedTree passed to a renderer was produced by a
canonical model’s to_verified_tree() call, not constructed ad-hoc or
bypassed.
Any frontend renderer that requires this proof can only be invoked after
to_verified_tree() has been called, giving all frontends contractually
enforced equivalency at the type level.