pub struct WcagAudioControlAvailable;Expand description
A mechanism is available to pause, stop, or adjust audio that plays automatically for more than 3 seconds.
Source: WCAG 2.2 SC 1.4.2 — Audio Control (Level A).