pub struct WcagReadingLevelSupplemented;Expand description
When content requires reading ability more advanced than lower secondary education, supplemental content or a simpler version is available.
Source: WCAG 2.2 SC 3.1.5 — Reading Level (Level AAA).